# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2022-2024, by Samuel Williams.

require_relative 'test/version'

require_relative 'test/detect'
require_relative 'test/runner'
